function [paw runoff etccum] = pawmodfunction(a,b,c,d,e,f,g,h,i,j,k,l,m,n)
% This plant available water model consists in a function to calculate the 
% water that is available for crops in a given soil profile, crop evapotrasnpiration,
% and runoff. In order to obtain the mentioned variables the model requires the input 
% of 14 parameters. Tentative values can be obtained from table 1 (below).
%
% EXAMPLE ON HOW TO TYPE THE FORMULA, you can copy and paste the following command
% in the command window. Then press enter. Remove semicon if you want to
% display the results in the main screen. Results are also stored in
% "Climate.xlsx"
%
% [paw runoff etccum] = pawmodfunction (60,140,0.3,0.1,0.65,25,65,100,123,0.35,0.8,1.0,0.6,35);
%
%   Table 1: orientative parameters for Sunflower (Helianthus annus) at Lahoma, OK 
%
%   Parameter	Meaning                  Unit         Range        Suggested Values
%       a       PAW initial              mm           0-350              60
%       b       Soil Depth               cm           0-300              140
%       c       Mean Field Capacity      cm3 cm-3	   0.2-0.35            0.29
%       d       Mean Wilting Point       cm3 cm-3	   0.05-0.2	           0.13
%       e       Stress Treshold          unitless	   0-1                 0.5-0.65
%       f       DAP Kc initial	                                         25
%       g       DAP Kc development       days after planting             60
%       h       DAP Kc mid season        at which stages finish          100
%       i       DAP Kc late season                                       123 
%       j       Kc initial	unitless                   0.2-0.5            0.4*
%       k       Kc development                        0.5-0.8            0.7*
%       l       Kc mid season                         0.8-1.4            1.0*
%       m       Kc late season                        0.5-0.8            0.6*
%       n       Curve Number$                         0-100       Try 35 and then 90
%
% * Values were obtained from Food and Agriculture Organization (FAO)
% $ Curve Number: usually ranges from 30 to 100. The greater the number the
% more susceptible to occur runoff. Flat fields can be in the range of 30
% to 50; and field with 3-5% of slope might go up to a value of about 90.
%
%   DAP Kc late season should match the total days of the simulation. 
%   In this case should be always 123 days.
%
%   EXECUTING THE MODEL AS A FUNCTION
%       1-	Call the function by writing in the command window [paw runoff etccum] = pawmodfunction (). 
%   You can copy what is below to save time. Then change values according to Table 1.
%   [paw runoff etccum] = pawmodfunction (60,140,0.29,0.13,0.65,25,65,100,123,0.35,0.8,1.0,0.6,35);
%   
%       2-	When you open parenthesis the function will ask you for parameters that go from a to n.
%
%   EXECUTING THE MODEL USING GUI
%       1-Execute the GUI by typing pawmod2 in the windows command. The main window of the model should open (Figure 1)
%
%
%                                                                  
%
%
%

pawi=a; %initial plant available water. This value extremely importat because
%the model strongly depends on it.
depth=b; %cm It is recommentded to use potential root zone for a given crop and environment.
%Shallow depths may lead to errors, due to the model does not account for
%soil water flow.
thetafc=c; %cm3 cm-3, volumentric water content of the field capacity value
%value obtained by
thetawp=d; %cm3 cm-3, volumetric water content that corresponds to wilting point,
%value usually obtained by air pressure of 1500 kPa.
fc=thetafc*depth*10; %mm  field capacity affected by soil depth to obtain 
%the layer of water in mm, which is independent of the area.
wp=thetawp*depth*10; %mm same than above, but for wilting point
aw=fc - wp; %mm Maximum plant available water
treshold=e; %unitless, ratio that determines where the model starts accounting for
%less evapotrasnpiration due to water stress in the plant, or less water
%availability for evaporation in the soil.
stress=aw*treshold; %gives the stress factor in mm
t = xlsread('Climate.xlsx', 1, 'B:B'); %days, reads time from excel file
eto = xlsread('Climate.xlsx', 1, 'C:C'); %reads reference ETo from file
rainfall = xlsread('Climate.xlsx', 1, 'D:D'); %reads rainfall from file
pawm = xlsread('Climate.xlsx', 1, 'E:E'); %reads potential empirical paw adjustments from file
dapKci=f; %days after planting at which the first crop phenological stage ends.
dapKcdev=g; %days after planting at which the development stage ends
dapKcmid=h; %days after planting at which the middle stage ends (this stage is usually
%when the crop has its highest Kc).
dapKclate=i; %days after planting at which the last stage (senescese) ends.
Kci=j; %value of the Kc for the initial stage
Kcdev=k; %value of the Kc for the development stage.
Kcmid=l; %value of the Kc for the middle stage of the crop
Kclate=m; %Kc value of the last crop stage
cn=n; %curve number. Usually flat landscapes are about 30-45. Tilt landscapes can have a curve number of 75-95.
%Impervious surfaces should have a value of 100.
s=(1000/cn-10);
lambda=0.2; %specific coeficient. 0.02 sometimes is recommended for no-till systems.
Ia=s*lambda;
w=max (t);

paw=(1:w)'; paw(1)=pawi;  Kc=(1:w)'; Kc(1)=Kci; %definition of the size of the row vectors
for n=(2:w); % distribution of the Kc according to crop stages length from the second day in advance. 
    %The first day is the value obtained from pawi.
  for n=2:dapKci; 
      Kc(n)=Kci;
  for n=dapKci+1:dapKcdev;
      Kc(n)=Kcdev;
  for n=dapKcdev+1:dapKcmid;
      Kc(n)=Kcmid;
  for n=dapKcmid+1:dapKclate;
      Kc(n)=Kclate;
  end
  end
  end
  end
end

etc=(1:w)'; etc(1)=Kci*eto(1); Kcadj=(1:w)'; Kcadj(1)=Kci; runoff=(1:w)'; runoff(1)= 0;
rainfalleffective=(1:w)'; rainfalleffective(1)=rainfall(1); etccum=(1:w)'; etccum(1)=Kci*eto(1);
for n=(2:w)
      
      if (paw(n-1)/aw<treshold); %if the ratio between actual paw and maximum paw is less than the treshold,
          %then the Kc is adjusted proportionally to the actual paw.
          
           Kcadj(n)= (Kc(n).*((paw(n-1)/aw)/treshold));
      else 
          Kcadj(n)=Kc(n);
          
      end
       if ((rainfall(n)/25.4>0)&&(rainfall(n)/25.4>Ia)) %transforms rainfall from mm to inches. Curve number method was developed 
           %to work with rainfall in inches.
          runoff(n)=(((rainfall(n)/25.4-Ia)^2/((rainfall(n)/25.4)-Ia+s))*25.4);
          rainfalleffective(n)=rainfall(n)-runoff(n); 
      else
          runoff(n)=0;
          rainfalleffective(n)=rainfall(n);
      end
              
    if (pawm(n)> 0);
       paw(n-1)=pawm(n);
    end
   
    etc(n)=eto(n).*(Kcadj(n)); %calculates to evapotrasnpiration of the crop for n days
    paw(n)=paw(n-1)+ rainfalleffective(n)-etc(n); %calculates the paw for n days
    etccum(n)=etccum(n-1)+etc(n);       
end

   
subplot(2,2,1), plot(t,paw,t,stress)%subplot command divides the screen in 2 rows and 2 columns
set(gca,'YTick',0:50:300) %keeps Y axis constant, independently of the values of the
%dependent variable.
title('PAW vs Time');
ylabel('PAW (mm)');

subplot (2,2,2), plot(t, etccum)
set(gca,'YTick',0:50:300);
ylabel('ETc (mm)');
title('ETc vs Time');

subplot (2,2,3), plot(t, rainfall)
set(gca,'YTick',0:20:100)
title('Rainfall vs Time');
ylabel('Rainfall (mm)');
xlabel('Time (days)');

subplot (2,2,4), plot(t, runoff)
set(gca,'YTick',0:20:100);
title('Runoff vs Time');
xlabel('Time (days)');
ylabel('Runoff (mm)');

d= {'PAW (mm)','ETc (mm)','Runoff (mm)','ETc Cumulative (mm)'}; %generates the row vector that will constitute the column headers.
xlswrite('Climate.xlsx', d, 1, 'F11'); %writes headers in excel file
xlswrite('Climate.xlsx', paw, 1, 'F12') %exports paw to excel file, from cell F12
xlswrite('Climate.xlsx', etc, 1, 'G12') %same for etc from cell G12
xlswrite('Climate.xlsx', runoff, 1, 'H12')%same for runoff from cell H12
xlswrite('Climate.xlsx', etccum, 1, 'I12')% same for cumulative etc from cell I12
warning off MATLAB:xlswrite:AddSheet %avoids a frequent error message .
%Developed by Andres Patrignani as part of Soil Physics Theroy 6110 course
%at Oklahoma State University. 2011.
%Professor: Dr. Tyson Ochsner

        

